@@ -6,8 +6,9 @@ from datetime import datetime
 from enum import Enum
 from typing import List, Optional
 
-from pydantic import BaseModel, Field
+from pydantic import Field
 
+from ..device import Device
 from ..base import AindSchema
 
 
@@ -30,13 +31,10 @@ class CameraName(Enum):
     FACE_CAMERA = "Face Camera"
 
 
-class Camera(BaseModel):
+class Camera(Device):
     """Description of camera"""
 
     name: CameraName = Field(..., title="Name")
-    manufacturer: str = Field(..., title="Manufacturer")
-    model: str = Field(..., title="Model")
-    serial_number: str = Field(..., title="Serial number")
     position_x: float = Field(..., title="Position X")
     position_y: float = Field(..., title="Position Y")
     position_z: float = Field(..., title="Position Z")
@@ -62,7 +60,7 @@ class Surface(Enum):
     FOAM = "foam"
 
 
-class Disc(BaseModel):
+class Disc(Device):
     """Description of a running disc"""
 
     radius: float = Field(..., title="Radius (cm)", units="cm", ge=0)
@@ -79,13 +77,10 @@ class LaserName(Enum):
     LASER_B = "Laser B"
 
 
-class Laser(BaseModel):
+class Laser(Device):
     """Description of lasers used in ephys recordings"""
 
     name: LaserName = Field(..., title="Laser Name")
-    manufacturer: str = Field(..., title="Manufacturer")
-    model: str = Field(..., title="Model")
-    serial_number: str = Field(..., title="Serial number")
     wavelength: Optional[int] = Field(
         None, title="Wavelength (nm)", units="nm", ge=300, le=1000
     )
@@ -107,12 +102,9 @@ class Laser(BaseModel):
     )
 
 
-class Monitor(BaseModel):
+class Monitor(Device):
     """Description of a visual monitor"""
 
-    manufacturer: str = Field(..., title="Manufacturer")
-    model: str = Field(..., title="Model")
-    serial_number: str = Field(..., title="Serial number")
     refresh_rate: int = Field(
         ..., title="Refresh rate (Hz)", units="Hz", ge=60
     )
@@ -179,17 +171,28 @@ class ProbeType(Enum):
     MP_PHOTONIC_V1 = "MPI Photonic Probe (Version 1)"
 
 
-class Probe(BaseModel):
+class Probe(Device):
     """Description of an ephys probe"""
 
     name: ProbeName = Field(..., title="Name")
     type: ProbeType = Field(..., title="Type")
-    serial_number: str = Field(..., title="Serial number")
 
 
-class Devices(BaseModel):
-    """All of the devices in the rig"""
+class EphysRig(AindSchema):
+    """Description of an ephys rig"""
 
+    describedBy: str = Field(
+        "https://github.com/AllenNeuralDynamics/data_schema/blob/main/schemas/ephys/ephys_rig.py",
+        description="The URL reference to the schema.",
+        title="Described by",
+        const=True,
+    )
+    schema_version: str = Field(
+        "0.3.0", description="schema version", title="Version", const=True
+    )
+    rig_id: str = Field(
+        ..., description="room_stim apparatus_version", title="Rig ID"
+    )
     probes: Optional[List[Probe]] = Field(
         None, title="Probes", unique_items=True
     )
@@ -203,16 +206,6 @@ class Devices(BaseModel):
         None, title="Visual monitor", unique_items=True
     )
     running_disc: Optional[Disc] = Field(None, title="Running disc")
-    harp_devices: Optional[List[HarpDevice]] = None
-
-
-class EphysRig(AindSchema):
-    """Description of an ephys rig"""
-
-    schema_version: str = Field(
-        "0.2.0", description="schema version", title="Version", const=True
+    harp_devices: Optional[List[HarpDevice]] = Field(
+        None, title="Harp devices"
     )
-    rig_id: str = Field(
-        ..., description="room_stim apparatus_version", title="Rig ID"
-    )
-    devices: Devices
